@@ -47,6 +47,29 @@ void Bookmarks::loadBook()
 
     if ( list[0] == "nothing" ) return;
 
+
+ /*   QPixmap temp;
+    // First of all, make a backup of the original image
+    if ( ! QFileInfo("path/to/image_orig.png").exists() )
+    {
+        temp = QPixmap("path/to/image.png");
+        temp.save("path/to/image_orig.png");
+    }
+    // Set image opacity using the original image we have created
+    temp = QPixmap("path/to/image_orig.png");
+    QPixmap transparent(temp.size());
+    transparent.fill(Qt::transparent);
+    QPainter p(&transparent);
+    p.setCompositionMode(QPainter::CompositionMode_Source);
+    p.drawPixmap(0, 0, temp);
+    p.setCompositionMode(QPainter::CompositionMode_DestinationIn);
+    p.fillRect(transparent.rect(), QColor(0, 0, 0, 150));  // 150 is the opacity, value can be 0-255
+    p.end();
+    // Save the new image
+    transparent.save("path/to/image.png");
+*/
+
+
     for (int j=0; j < list.count(); ++j)
     {
         QListWidgetItem *item1 = new QListWidgetItem( ui->listWidget );
