@@ -610,6 +610,16 @@
         <source>Deleting</source>
         <translation>Borrando</translation>
     </message>
+    <message>
+        <location filename="../askdialog.cpp" line="10"/>
+        <source>Change icon</source>
+        <translation>Cambiar icono</translation>
+    </message>
+    <message>
+        <location filename="../askdialog.cpp" line="10"/>
+        <source>Apply to subfolders?</source>
+        <translation>Aplicar a subcarpetas?</translation>
+    </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Are you sure you want to delete %1?</source>
