@@ -132,7 +132,7 @@
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Symlink destination</source>
-        <translation>Symbolisk känk här</translation>
+        <translation>Plats för symbolisk länk</translation>
     </message>
 </context>
 <context>
