@@ -476,6 +476,7 @@ void MainWindow::agregarArchivo(QString archivo)
     QString iconSet = settings.value("IconStyle", "Default").toString();
     QString descripcion, icono1;
     QListWidgetItem *item1 = new QListWidgetItem( ui->listWidget );
+    QString dateSep = QDate::currentDate().toString(Qt::SystemLocaleShortDate).remove(QRegExp("\\d+")).at(0);
 
     /*QString itemname = sPath + "/" + fileInfo.fileName();
     if ( itemname == "/home/user/MyDocs/.documents" ) itemname = tr("Documents");
@@ -617,10 +618,8 @@ void MainWindow::agregarArchivo(QString archivo)
         {
             if ( ! fileInfo.exists() )
                 descripcion = "brokenlink";
-            else if ( QLocale::languageToString(QLocale::system().language()) == "English" )
-                descripcion = QString("%1 %2 - %3").arg(fileInfo.lastModified().date().toString("MM/dd/yyyy")).arg(fileInfo.lastModified().time().toString("HH:mm:ss")).arg(GetFileSize(fileInfo.size()));
-            else
-                descripcion = QString("%1 %2 - %3").arg(fileInfo.lastModified().date().toString("dd/MM/yyyy")).arg(fileInfo.lastModified().time().toString("HH:mm:ss")).arg(GetFileSize(fileInfo.size()));
+            else 
+                descripcion = QString("%1 %2 - %3").arg(fileInfo.lastModified().date().toString(Qt::SystemLocaleShortDate)+dateSep+fileInfo.lastModified().date().toString("yyyy")).arg(fileInfo.lastModified().time().toString("HH:mm:ss")).arg(GetFileSize(fileInfo.size()));
         }
         else descripcion = "";
 
